package com.xingxi.master.product.mapper;

import com.xingxi.master.product.domain.Prod;

import java.util.List;

/**
 * 商品Mapper接口
 *
 * @author xingxi
 * @date 2025-03-06
 */
public interface ProdMapper {
    /**
     * 查询商品
     *
     * @param id 商品主键
     * @return 商品
     */
    Prod selectProdById(Long id);

    /**
     * 查询商品列表
     *
     * @param prod 商品
     * @return 商品集合
     */
    List<Prod> selectProdList(Prod prod);

    /**
     * 新增商品
     *
     * @param prod 商品
     * @return 结果
     */
    int insertProd(Prod prod);

    /**
     * 批量新增商品
     *
     * @param prodList 商品
     * @return 结果
     */
    int batchInsertProd(List<Prod> prodList);

    /**
     * 修改商品
     *
     * @param prod 商品
     * @return 结果
     */
    int updateProd(Prod prod);

    /**
     * 删除商品
     *
     * @param id 商品主键
     * @return 结果
     */
    int deleteProdById(Long id);

    /**
     * 批量删除商品
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteProdByIds(String[] ids);


    /**
     * 逻辑删除商品
     *
     * @param id 商品主键
     * @return 结果
     */
    int logicDeleteProdById(Long id);

    /**
     * 逻辑批量删除商品
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int logicDeleteProdByIds(String[] ids);

    /**
     * 逻辑批量删除商品
     *
     * @param prod 商品
     * @return 结果
     */
    int logicDeleteProdByCondition(Prod prod);

}
